:html_theme.sidebar_secondary.remove:

.. include:: ../README.rst
    :end-before: when included in index.rst

How the documentation is structured
-----------------------------------

The documentation consists of a Developer Guide for MX-Bluesky, which also includes documentation for Hyperion. At its current stage in development, there is no user guide.

.. grid:: 1

    .. grid-item-card:: :material-regular:`code;4em`
        :link: developer/index
        :link-type: doc

        The Developer Guide contains documentation on how to install, develop and contribute changes to MX-Bluesky; explanations about the purpose of the software and some of the technical concepts; as well as how-to guides and tutorials.

.. toctree::
    :hidden:

    developer/index
